==> geant4.9.5.p02.tar.gz: geant4.9.5.p02/source/processes/hadronic/models/im_r_matrix/src/G4CollisionNNToNDelta.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id: G4CollisionNNToNDelta.cc,v 1.5 2010-03-12 15:45:18 gunter Exp $ //

#include "globals.hh"
#include "G4CollisionNNToNDelta.hh"
#include "G4ConcreteNNToNDelta.hh"
#include "G4ShortLivedConstructor.hh"

G4CollisionNNToNDelta::G4CollisionNNToNDelta()
{ 
  G4ShortLivedConstructor ShortLived;
  ShortLived.ConstructParticle();
  MakeNNToNDelta<DeltamPC, Delta0PC, DeltapPC, DeltappPC, G4ConcreteNNToNDelta>::Make(this);
}

==> geant4.10.00.p03.tar.gz: geant4.10.00.p03/source/processes/hadronic/models/im_r_matrix/src/G4CollisionNNToNDelta.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// $Id: G4CollisionNNToNDelta.cc,v 1.5 2010-03-12 15:45:18 gunter Exp $ //

#include "globals.hh"
#include "G4CollisionNNToNDelta.hh"
#include "G4ConcreteNNToNDelta.hh"
#include "G4ShortLivedConstructor.hh"

G4CollisionNNToNDelta::G4CollisionNNToNDelta()
{ 
	components=0;
	G4ShortLivedConstructor ShortLived;
	ShortLived.ConstructParticle();
	MakeNNToNDelta<DeltamPC, Delta0PC, DeltapPC, DeltappPC, G4ConcreteNNToNDelta>::Make(this);
}

G4CollisionNNToNDelta::~G4CollisionNNToNDelta()
{
	if (components) delete components;
	components=0;
}
